{% load cms_tags frontend %}
<{{ instance.tag_type }}{{ instance.get_attributes }}>
{% if mixin_link %}
    <a href="{{ mixin_link }}"{% if instance.target %} target="{{ instance.target }}"{% endif %}>
{% endif %}
{% with image=carousel_image.image %}
    {% include "djangocms_frontend/bootstrap5/carousel/default/image.html" %}
{% endwith %}
{% if mixin_link %}
    </a>
{% endif %}
<div class="carousel-caption d-none d-md-block">
    {% if instance.carousel_content %}
        {{ instance.carousel_content|html_safe }}
    {% endif %}
    {% if instance.rel_image %}
        {% for plugin in instance.child_plugin_instances %}
            {% render_plugin plugin %}
        {% endfor %}
    {% endif %}
</div>
</{{ instance.tag_type }}>
