{% load i18n menu_tags cache %}
  {% for child in children %}
    <a href="{{ child.get_absolute_url }}" class="block px-4 py-2 text-sm text-gray-700{% if child.selected %} bg-gray-100{% endif %}" role="menuitem" tabindex="-1">{{ child.get_menu_title }}</a>
  {% endfor %}
</div>
