.djangocms-admin-style .form-row.field-plugin_title {
    input[name="plugin_title_0"] {
        margin-bottom: 0.5em !important;
    }

    input[name="plugin_title_1"] {
        width: calc(100% - 2em) !important;
    }
}

body:not(.djangocms-admin-style) .form-row.field-plugin_title {
    input[name="plugin_title_1"] {
        width: calc(100% - 200px - 1em) !important;
        margin-inline-start: 1em;
    }
}
