{% load cms_tags frontend %}
<{{ instance.tag_type }}{{ instance.get_attributes }} {% set_html_id instance as html_id %}id="parent-{{ html_id }}">
    {% for plugin in instance.child_plugin_instances %}
        {% with parentloop=forloop parent=instance %}{% render_plugin plugin %}{% endwith %}
    {% empty %}{% user_message _("Add accordion items here") %}
    {% endfor %}
</{{ instance.tag_type }}>
